@@ -1,7 +1,16 @@
-from .const import ConnectionInfo, DoorStatus, LockInfo, LockState, LockStatus
+from bleak_retry_connector import close_stale_connections_by_address
+
+from .const import (
+    ConnectionInfo,
+    DoorStatus,
+    LockInfo,
+    LockState,
+    LockStatus,
+    YaleXSBLEDiscovery,
+)
 from .lock import Lock
 from .push import PushLock
-from .session import AuthError, DisconnectedError
+from .session import AuthError, DisconnectedError, YaleXSBLEError
 from .util import (
     ValidatedLockConfig,
     local_name_is_unique,
@@ -11,7 +20,7 @@ from .util import (
     unique_id_from_local_name_address,
 )
 
-__version__ = "1.9.2"
+__version__ = "2.5.0"
 
 __all__ = [
     "AuthError",
@@ -29,4 +38,7 @@ __all__ = [
     "unique_id_from_device_adv",
     "unique_id_from_local_name_address",
     "local_name_is_unique",
+    "YaleXSBLEDiscovery",
+    "YaleXSBLEError",
+    "close_stale_connections_by_address",
 ]
